@@ -235,10 +235,10 @@ class iS3PythonApi:
         return output_folder_path
 
     '''
-            预处理 JSON 数据并将其保存到指定的输出文件夹中。
+            文件预下载到指定目录，local进行copy，online进行下载。
     
             :param jsonData: 要处理的 JSON 数据，应该是字典或列表。
-            :param outputFolderPath: 输出文件夹路径，用于保存处理后的 JSON 文件。
+            :param outputFolderPath: 输出文件夹路径。
     '''
 
     def preDownload(self, jsonData, outputFolderPath):
